@@ -62,7 +62,7 @@ class Base(object):
         pass
 
     def run(self):
-        raise NotImplemented
+        raise NotImplementedError
 
     def get_query(self):
         t = db.metadata.tables
@@ -128,7 +128,7 @@ class XmlExportBase(Base):
         self.false_value     = 'False'
 
     def run(self):
-        if self.show_dialog() == True:
+        if self.show_dialog() is True:
             # create xml document
             impl = xml.dom.minidom.getDOMImplementation()
             doc  = impl.createDocument(None, None, None)
@@ -141,7 +141,7 @@ class XmlExportBase(Base):
         # shows a file dialog and sets self.filepath
         # derived classes which overwrite this method have also to set self.filepath
         basedir = None
-        if not self.config is None and not self.config_section is None:
+        if self.config is not None and self.config_section is not None:
             basedir = self.config.get('export_dir', None, section=self.config_section)
         if basedir is None:
             filenames = gutils.file_chooser(_('Export a %s document') % self.export_name, action=Gtk.FileChooserAction.SAVE, \
@@ -156,7 +156,7 @@ class XmlExportBase(Base):
             else:
                 self.dirpath = os.path.dirname(self.filepath)
             self.filename = os.path.basename(self.filepath)
-            if not self.config is None and self.dirpath and not self.config_section is None:
+            if self.config is not None and self.dirpath and self.config_section is not None:
                 self.config.set('export_dir', self.dirpath, section=self.config_section)
                 self.config.save()
             overwrite = None
@@ -166,7 +166,7 @@ class XmlExportBase(Base):
                 else:
                     overwrite = False
 
-            if overwrite == True or overwrite is None:
+            if overwrite is True or overwrite is None:
                 return True
         return False
 
@@ -325,7 +325,7 @@ class XmlExportBase(Base):
             columns = languagecolumns, \
             from_obj = [language_join, acodec_join], \
             whereclause = and_(db.metadata.tables['movie_lang'].c.movie_id==movie['movies_movie_id'], \
-                or_(db.metadata.tables['movie_lang'].c.type==0, or_(db.metadata.tables['movie_lang'].c.type==2, db.metadata.tables['movie_lang'].c.type==None))), \
+                or_(db.metadata.tables['movie_lang'].c.type==0, or_(db.metadata.tables['movie_lang'].c.type==2, db.metadata.tables['movie_lang'].c.type is None))), \
             use_labels = True)
         self.process_languages(document, movieelement, languagesquery)
 
@@ -371,7 +371,7 @@ class XmlExportBase(Base):
         if not os.path.exists(dst_directory):
             try:
                 os.mkdir(dst_directory)
-            except:
+            except Exception:
                 log.error("Can't create %s" % dst_directory)
         dst_filename = os.path.join(dst_directory, imagebasename + '.jpg')
         try:
@@ -380,7 +380,7 @@ class XmlExportBase(Base):
                 f.write(imagedata)
             finally:
                 f.close()
-        except:
+        except Exception:
             log.error("Can't save image data to %s" % dst_filename)
 
     def convert_value(self, value):
@@ -393,7 +393,7 @@ class XmlExportBase(Base):
         else:
             try:
                 result = str(value).encode(self.encoding).decode(self.encoding)
-            except:
+            except Exception:
                 log.error('Can''t convert value ' + value + ' to codepage ' + self.encoding + '.')
                 result = ''
         return result
